tdub.hist
---------

A module for histogramming

.. currentmodule:: tdub.hist

Class Summary
^^^^^^^^^^^^^

.. autosummary::

   SystematicComparison

Function Summary
^^^^^^^^^^^^^^^^

.. autosummary::

   bin_centers
   edges_and_centers
   to_uniform_bins

Reference
^^^^^^^^^

.. autoclass:: SystematicComparison
   :members:

.. autofunction:: bin_centers
.. autofunction:: edges_and_centers
.. autofunction:: to_uniform_bins
